migrate_ecotox_path: Temporary function to switch to new ECOTOX path

View source: R/init.r

migrate_ecotox_pathR Documentation

Temporary function to switch to new ECOTOX path

Description

Since ECOTOXr v1.2.5, the path is located with the base package tools instead of the previously used rappdirs. Use this function to migrate your old files to this new location.

Usage

migrate_ecotox_path(overwrite = FALSE)

Arguments

overwrite

logical value. Should files that already exist in the new location be overwritten?

Value

Returns NULL invisibly.

See Also

Other database-access-functions: check_ecotox_availability(), check_ecotox_build(), check_ecotox_version(), cite_ecotox(), dbConnectEcotox(), get_ecotox_info(), get_ecotox_sqlite_file(), list_ecotox_fields()


ECOTOXr documentation built on July 9, 2026, 9:07 a.m.